@@ -1,27 +1,28 @@
 #' 'ggplot2' geoms to add text labels to treemap subgroups.
 #'
-#' When `geom_treemap` is used with the `subgroup`, `subgroup2` or `subgroup3`
-#' aesthetic to subgroup treemap tiles, `geom_treemap_subgroup_text`,
-#' `geom_treemap_subgroup2_text` or `geom_treemap_subgroup3_text` can be used
-#' to add a text label to each subgroup at the appropriate level.
+#' When `geom_treemap()` is used with the `subgroup`, `subgroup2` or
+#' `subgroup3` aesthetic to subgroup treemap tiles,
+#' `geom_treemap_subgroup_text()`, `geom_treemap_subgroup2_text()` or
+#' `geom_treemap_subgroup3_text()` can be used to add a text label to each
+#' subgroup at the appropriate level.
 #'
-#' `geom_treemap_subgroup_text` geoms require `area`, `label` and `subgroup`
+#' `geom_treemap_subgroup_text()` geoms require `area`, `label` and `subgroup`
 #' (or `subgroup2`, `subgroup3`) aesthetics. Several other standard 'ggplot2'
 #' aesthetics are supported (see Aesthetics).
 #'
-#' `geom_treemap_subgroup_text` geoms use the 'ggfittext' package to fit text
+#' `geom_treemap_subgroup_text()` geoms use the 'ggfittext' package to fit text
 #' to the subgroup. All text drawing options available in
-#' `ggfittext::geom_fit_text` (growing, reflowing, etc.) are also available
+#' `ggfittext::geom_fit_text()` (growing, reflowing, etc.) are also available
 #' here. For full details on how these options work, see the documentation for
-#' `ggfittext::geom_fit_text`.
+#' `ggfittext::geom_fit_text()`.
 #'
 #' The `layout` argument is used to set the treemap layout algorithm. All
-#' `treemapify` geoms added to a plot should have the same value for `layout`
-#' and `start`, or they will not share a common layout (see `geom_treemap` for
-#' details on the layout algorithms).
+#' 'treemapify' geoms added to a plot should have the same value for `layout`
+#' and `start`, or they will not share a common layout (see `geom_treemap()`
+#' for details on the layout algorithms).
 #'
-#' @param padding.x,padding.y `grid::unit` object, giving horizontal or vertical
-#' padding between text and edge of tile. Defaults to 1 mm.
+#' @param padding.x,padding.y `grid::unit()` object, giving horizontal or
+#' vertical padding between text and edge of tile. Defaults to 1 mm.
 #' @param place Where inside the box to place the text. Default is `bottom`;
 #' other options are `topleft`, `top`, `topright`, etc.
 #' @param min.size Minimum font size, in points. If provided, text that would
@@ -30,8 +31,8 @@
 #' @param grow If `TRUE`, text will be grown as well as shrunk to fill the box.
 #' @param reflow If `TRUE`, text will be reflowed (wrapped) to better fit the
 #' box.
-#' @param layout The layout algorithm, one of either "squarified" (the
-#' default), "scol", "srow" or "fixed". See Details for full details on the
+#' @param layout The layout algorithm, one of either 'squarified' (the
+#' default), 'scol', 'srow' or 'fixed'. See Details for full details on the
 #' different layout algorithms.
 #' @param start The corner in which to start placing the tiles. One of
 #' 'bottomleft' (the default), 'topleft', 'topright' or 'bottomright'.
@@ -39,26 +40,24 @@
 #' geom arguments as for `ggplot2::geom_text`.
 #' @param level One of 'subgroup', 'subgroup2' or 'subgroup3', giving the
 #' subgrouping level for which to draw text labels. It is recommended to use
-#' the aliases `geom_treemap_subgroup2_text` and `geom_treemap_subgroup3_text`
-#' instead of this argument.
+#' the aliases `geom_treemap_subgroup2_text()` and
+#' `geom_treemap_subgroup3_text()` instead of this argument.
 #' @param fixed Deprecated. Use `layout = "fixed"` instead. Will be removed in
 #' later versions.
 #'
-#' @seealso geom_treemap, geom_treemap_subgroup_border
+#' @seealso [geom_treemap()], [geom_treemap_subgroup_border()]
 #'
 #' @section Aesthetics:
 #'
-#' \itemize{
-#'   \item area (required)
-#'   \item subgroup, subgroup2 or subgroup3 (required; the value of this
-#'   variable will be the text label)
-#'   \item colour
-#'   \item size
-#'   \item alpha
-#'   \item family
-#'   \item fontface
-#'   \item angle
-#' }
+#' - area (required)
+#' - subgroup, subgroup2 or subgroup3 (required; the value of this variable
+#' will be the text label)
+#' - colour
+#' - size
+#' - alpha
+#' - family
+#' - fontface
+#' - angle
 #' 
 #' @examples
 #'
@@ -201,6 +200,11 @@ GeomSubgroupText <- ggplot2::ggproto(
     data <- do.call(treemapify, params)
     names(data)[names(data) == level] <- "label"
 
+    # Standardise the place argument
+    if (place %in% c("middle", "center")) {
+      place <- "centre"
+    }
+
     # Use treemapify's fittexttree to draw text
     grob <- grid::gTree(
       data = data,
